@@ -15,16 +15,19 @@
 #' @details If a transformation was used when `x` was created, the inverse is
 #'  applied _before_ the difference is computed.
 #' @export
-contrast_models <- function(x, list_1 = NULL, list_2 = NULL,
-                            seed = sample.int(10000, 1)) {
+contrast_models <- function(
+  x,
+  list_1 = NULL,
+  list_2 = NULL,
+  seed = sample.int(10000, 1)
+) {
   if (is.null(list_1) & is.null(list_2)) {
     combos <- combn(x$names, 2)
     list_1 <- combos[1, ]
     list_2 <- combos[2, ]
   } else {
     if (length(list_1) != length(list_2)) {
-      rlang::abort("`list_1` and `list_2` should be the same length."
-      )
+      rlang::abort("`list_1` and `list_2` should be the same length.")
     }
   }
 
@@ -36,7 +39,7 @@ contrast_models <- function(x, list_1 = NULL, list_2 = NULL,
       obj = x$stan,
       trans = x$transform,
       seed = seed
-    ) %>%
+    ) |>
     dplyr::mutate(contrast = paste(model_1, model_2, sep = " vs. "))
   diffs <- tibble::as_tibble(diffs)
   class(diffs) <- c("posterior_diff", class(diffs))
@@ -81,22 +84,22 @@ print.posterior_diff <- function(x, ...) {
 #' summary(contrast_samples)
 #' summary(contrast_samples, size = 0.025)
 summary.posterior_diff <- function(object, prob = 0.90, size = 0, ...) {
-  object <- object %>%
-    dplyr::mutate(contrast = paste(model_1, model_2, sep = " vs ")) %>%
+  object <- object |>
+    dplyr::mutate(contrast = paste(model_1, model_2, sep = " vs ")) |>
     dplyr::rename(posterior = difference)
-  post_int <- object %>%
-    dplyr::group_by(contrast) %>%
+  post_int <- object |>
+    dplyr::group_by(contrast) |>
     dplyr::do(postint.data.frame(., prob = prob))
-  post_stats <- object %>%
-    dplyr::group_by(contrast) %>%
+  post_stats <- object |>
+    dplyr::group_by(contrast) |>
     dplyr::summarise(
       probability = mean(posterior > 0),
       mean = mean(posterior)
-    ) %>%
+    ) |>
     dplyr::full_join(post_int, by = c("contrast"))
   if (size != 0) {
-    rope_stats <- object %>%
-      dplyr::group_by(contrast) %>%
+    rope_stats <- object |>
+      dplyr::group_by(contrast) |>
       dplyr::summarise(
         size = size,
         pract_neg = mean(posterior < -size),
@@ -104,8 +107,8 @@ summary.posterior_diff <- function(object, prob = 0.90, size = 0, ...) {
         pract_pos = mean(posterior > size)
       )
   } else {
-    rope_stats <- object %>%
-      dplyr::group_by(contrast) %>%
+    rope_stats <- object |>
+      dplyr::group_by(contrast) |>
       dplyr::summarise(
         size = size,
         pract_neg = na_dbl,
@@ -152,10 +155,9 @@ autoplot.posterior_diff <-
   }
 
 
-
 make_df <- function(a, b, id_vals = NULL) {
   new_dat <- data.frame(model = c(a, b))
-  as.data.frame(lapply(id_vals, function(x) rep(x[1], nrow(new_dat)))) %>%
+  as.data.frame(lapply(id_vals, function(x) rep(x[1], nrow(new_dat)))) |>
     dplyr::bind_cols(new_dat)
 }
 
